changeset 10595:47233c73ca58

Truffle-DSL: API change: Renamed createNodeSpecialized to createNodeGeneric. There was not a known use-case for createNodeSpecialized so we decided to replace it with a simpler version.
author Christian Humer <christian.humer@gmail.com>
date Mon, 01 Jul 2013 20:31:30 +0200
parents 72e6b178de16
children f43eb2f1bbbc
files graal/com.oracle.truffle.api.codegen/src/com/oracle/truffle/api/codegen/NodeFactory.java
diffstat 1 files changed, 2 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api.codegen/src/com/oracle/truffle/api/codegen/NodeFactory.java	Mon Jul 01 20:29:08 2013 +0200
+++ b/graal/com.oracle.truffle.api.codegen/src/com/oracle/truffle/api/codegen/NodeFactory.java	Mon Jul 01 20:31:30 2013 +0200
@@ -44,14 +44,13 @@
     T createNode(Object... arguments);
 
     /**
      * Instantiates a new specialized variant of the node. This is an optional method and throws an
      * {@link UnsupportedOperationException} if not supported.
      * 
      * @param thisNode the current node
-     * @param specializionClasses
      * @return the specialized node
      */
-    T createNodeSpecialized(T thisNode, Class<?>... specializionClasses);
+    T createNodeGeneric(T thisNode);
 
     /**
      * Returns the node class that will get created by {@link #createNode(Object...)}. The node
@@ -44,14 +44,13 @@
 
     /**
-     * Instantiates a new specialized variant of the node. This is an optional method and throws an
+     * Instantiates a new generic variant of the node. This is an optional method and throws an
      * {@link UnsupportedOperationException} if not supported.
      * 